# -*- coding: utf-8 -*-
from setuptools import setup

setup(
    name="pdfparanoia",
    version="0.0.2",
    url="https://github.com/kanzure/pdfparanoia",
    license="BSD",
    author="Bryan Bishop",
    author_email="kanzure@gmail.com",
    description="pdf watermark remover library for academic papers",
    long_description=open("README.md", "r").read(),
    packages=["pdfparanoia"],
    package_data={'': ['README.md']},
    include_package_data=True,
    zip_safe=False,
    install_requires=["pdfminer>=0", "pdfquery>=0"],
    platforms="any",
    classifiers=[
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        #"Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
    ]
)



# -*- coding: utf-8 -*-
"""
pdfparanoia.eraser
~~~~~~~~~~~~~~~

Tools to erase things from pdfs by direct manipulation of the pdf format.

"""

def remove_object_by_id(content, objid):
    """
    Deletes an object from a pdf. Mostly streams and FlateDecode stuff.
    """
    outlines = []
    lines = content.split("\n")
    last_line = None
    skip_mode = False
    for line in lines:
        if not skip_mode:
            if last_line in ["endobj", None]:
                if line[-3:] == "obj":
                    if line.startswith(str(objid) + " "):
                        skip_mode = True
                        last_line = line
                        continue
            outlines.append(line)
        elif skip_mode:
            if line == "endobj":
                skip_mode = False
        last_line = line
    output = "\n".join(outlines)
    return output

